Sponsors and Supporters
=======================

Please consider sponsoring urllib3 development, especially if your company
benefits from this library.

Your contribution will go towards adding new features to urllib3 and making
sure all functionality continues to meet our high quality standards.


v2.0 Sponsor Perks
------------------

.. important::

   `Get in contact <mailto:sethmichaellarson@gmail.com>`_ for additional
   details on sponsorship and perks before making a contribution
   through `GitHub Sponsors <https://github.com/sponsors/urllib3>`_ if you have questions.


Silver v2.0 Sponsor Perks
~~~~~~~~~~~~~~~~~~~~~~~~~

- Your organization name and URL permanently added
  to the **Sponsors and Grants** section below
- Thank you within the v2.0 release announcement
  and on Twitter from urllib3 maintainers

➤ `Contribute to the "Silver v2.0 Sponsor" tier <https://opencollective.com/urllib3/contribute/silver-v2-sponsor-20442/checkout>`_
on Open Collective.


Gold v2.0 Sponsor Perks
~~~~~~~~~~~~~~~~~~~~~~~~

- Organization logo and URL listed on top of the v2.0 Roadmap
- Call with one or more urllib3 maintainer(s) to discuss
  the v2.0 release and how it impacts your organization
- Your organization will be thanked within the v2.0 release
  announcement, within all blog posts and public updates related to v2.0
  development, and multiple thank-you's on Twitter from
  urllib3 maintainers throughout v2.0 development
- All perks from the **Silver v2.0 Sponsors Perks** above

➤ `Contribute to the "Gold v2.0 Sponsor" tier <https://opencollective.com/urllib3/contribute/gold-v2-sponsor-20443/checkout>`_
on Open Collective.


Sponsors and Grants
-------------------

A grant for contiguous full-time development has the biggest impact for
progress. Periods of 3 to 10 days allow a contributor to tackle substantial
complex issues which are otherwise left to linger until somebody can't afford
to not fix them.

Contact `@sethmlarson <https://github.com/sethmlarson>`_ or `@shazow <https://github.com/shazow>`_
to arrange a grant for a core contributor.

We also welcome sponsorship in the form of time. We greatly appreciate companies
who encourage employees to contribute on an ongoing basis during their work hours.
Let us know and we'll be glad to add you to our sponsors list.

* `GitCoin Grants <https://gitcoin.co/grants>`_ (2019-2020), sponsored `@sethmlarson <https://github.com/sethmlarson>`_
  and `@pquentin <https://github.com/pquentin>`_

* `Abbott <https://abbott.com>`_ (2018-2019), sponsored `@sethmlarson <https://github.com/sethmlarson>`_

* `Google Cloud Platform <https://cloud.google.com>`_ (2018-2019), sponsored `@theacodes <https://github.com/theacodes>`_

* `GOVCERT.LU <https://govcert.lu>`_ (October 23, 2018), sponsored `@sethmlarson <https://github.com/sethmlarson>`_

* `Akamai <https://akamai.com>`_ (2017-2018) sponsored `@haikuginger <https://github.com/haikuginger>`_

* `Hewlett Packard Enterprise <https://hpe.com>`_ (2016-2017) sponsored
  `@Lukasa <https://github.com/Lukasa>`_

* `Stripe <https://stripe.com>`_ (June 23, 2014)
